==> nextcloud-13.0.1.tgz: nextcloud/apps/files/l10n/nb.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "All files" : "Alle filer",
    "Recent" : "Nylig",
    "File could not be found" : "Filen ble ikke funnet",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Favorites" : "Favoritter",
    "Could not create folder \"{dir}\"" : "Klarete ikke å opprette mappe \"{dir}\"",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 Byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp size1} men bare {size2} er ledig",
    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
    "Not enough free space" : "Ikke nok ledig diskplass",
    "Uploading …" : "Laster opp…",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
    "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
    "Actions" : "Handlinger",
    "Download" : "Last ned",
    "Rename" : "Gi nytt navn",
    "Move or copy" : "Flytt eller kopier",
    "Target folder" : "Målmappe",
    "Delete" : "Slett",
    "Disconnect storage" : "Koble fra lagring",
    "Unshare" : "Avslutt deling",
    "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Velg",
    "Pending" : "Venter",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Klarte ikke å kopiere \"{file}\", målfilen finnes",
    "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
    "{newName} already exists" : "{newName} finnes allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create folder \"{dir}\" because it already exists" : "Klarete ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New" : "Ny",
    "{used} of {quota} used" : "{used} av {quota} brukt",
    "{used} used" : "{used} brukt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagringsplass for {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringsplass er nesten brukt opp ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : [" stemmer med '{filter}'"," stemmer med '{filter}'"],
    "View in folder" : "Vis i mappe",
    "Copied!" : "Kopiert!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte lenke (virker bare for brukere som har tilgang til denne fila/mappa)",
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n Byte"],
    "Favorited" : "Er favoritt",
    "Favorite" : "Gjør til favoritt",
    "New folder" : "Ny mappe",
    "Upload file" : "Last opp fil",
    "Not favorited" : "Ikke i favoritter",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av merkelappene",
    "Added to favorites" : "Lagt til i favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du la til {file} i dine favoritter",
    "You removed {file} from your favorites" : "Du fjernet {file} fra dine favoritter",
    "File changes" : "Filendringer",
    "Created by {user}" : "Opprettet av {user}",
    "Changed by {user}" : "Endret av {user}",
    "Deleted by {user}" : "Slettet av {user}",
    "Restored by {user}" : "Gjenopprettet av {user}",
    "Renamed by {user}" : "Navn endret av {user}",
    "Moved by {user}" : "Flyttet av {user}",
    "\"remote user\"" : "\"ekstern bruker\"",
    "You created {file}" : "Du opprettet {file}",
    "{user} created {file}" : "{user} opprettet {file}",
    "{file} was created in a public folder" : "{file} ble opprettet i en offentlig mappe",
    "You changed {file}" : "Du endret {file}",
    "{user} changed {file}" : "{user} endret {file}",
    "You deleted {file}" : "Du slettet {file}",
    "{user} deleted {file}" : "{user} slettet {file}",
    "You restored {file}" : "Du gjenopprettet {file}",
    "{user} restored {file}" : "{user} gjenopprettet {file}",
    "You renamed {oldfile} to {newfile}" : "Du endret navn på {oldfile} til {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} endret navn på {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttet {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttet {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har blitt lagt til eller fjernet fra dine <strong>favoritter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil eller mappe ble <strong>endret</strong> eller <strong>omdøpt</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mappe ble <strong>opprettet</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe ble <strong>slettet</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong> dine <em>(Kun strøm)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
    "Unlimited" : "Ubegrenset",
    "Upload (max. %s)" : "Opplasting (maks. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Største opplastingsstørrelse",
    "max. possible: " : "max. mulige:",
    "Save" : "Lagre",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta 5 minutter før endringene trer i kraft.",
    "Missing permissions to edit from here." : "Manglende rettigheter til å redigere herfra.",
    "%s of %s used" : "%s av %s brukt",
    "%s used" : "%s brukt",
    "Settings" : "Innstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Bruk adressen <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">for å få tilgang til dine filer via WebDAV</a>",
    "Cancel upload" : "Avbryt opplasting",
    "No files in here" : "Ingen filer her",
    "Upload some content or sync with your devices!" : "Last opp noe innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne tjeneren.",
    "No favorites yet" : "Ingen favoritter enda",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "Shared with you" : "Delt med deg",
    "Shared with others" : "Delt med andre",
    "Shared by link" : "Delt med lenke",
    "Tags" : "Merkelapper",
    "Deleted files" : "Slettede filer",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt",
    "Move" : "Flytt",
    "A new file or folder has been <strong>deleted</strong>" : "En ny fil eller mappe har blitt <strong>slettet</strong>",
    "A new file or folder has been <strong>restored</strong>" : "En ny fil eller mappe har blitt <strong>gjenopprettet</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Bruk denne adressen <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">for å få tilgang til dine filer via WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-14.0.1.tgz: nextcloud/apps/files/l10n/nb.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Lagring er midlertidig utilgjengelig",
    "Storage invalid" : "Lagringsplass ugyldig",
    "Unknown error" : "Ukjent feil",
    "All files" : "Alle filer",
    "Recent" : "Nylig",
    "Favorites" : "Favoritter",
    "File could not be found" : "Filen ble ikke funnet",
    "Move or copy" : "Flytt eller kopier",
    "Download" : "Last ned",
    "Delete" : "Slett",
    "Home" : "Hjem",
    "Close" : "Lukk",
    "Could not create folder \"{dir}\"" : "Klarete ikke å opprette mappe \"{dir}\"",
    "Upload cancelled." : "Opplasting avbrutt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke laste opp {filename} fordi det er en mappe eller har 0 Byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Ikke nok ledig plass. Du laster opp {size1} men bare {size2} er ledig",
    "Target folder \"{dir}\" does not exist any more" : "Målmappen \"{dir}\" finnes ikke lenger",
    "Not enough free space" : "Ikke nok ledig diskplass",
    "Uploading …" : "Laster opp…",
    "…" : "…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} av {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Målmappen finnes ikke lenger",
    "Error when assembling chunks, status code {status}" : "Feil under sammenkobling av biter, statuskode {status}",
    "Actions" : "Handlinger",
    "Rename" : "Gi nytt navn",
    "Copy" : "Kopier",
    "Target folder" : "Målmappe",
    "Disconnect storage" : "Koble fra lagring",
    "Unshare" : "Avslutt deling",
    "Could not load info for file \"{file}\"" : "Klarte ikke å hente informasjon som filen \"{file}\"",
    "Files" : "Filer",
    "Details" : "Detaljer",
    "Select" : "Velg",
    "Pending" : "Venter",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Operasjonen er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappen er utilgjengelig. Sjekk loggene eller kontakt administrator",
    "Could not move \"{file}\", target exists" : "Klarte ikke å flytte \"{file}\", målfilen finnes",
    "Could not move \"{file}\"" : "Klarte ikke å flytte \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Klarte ikke å kopiere \"{file}\", målfilen finnes",
    "Could not copy \"{file}\"" : "Klarte ikke å kopiere \"{file}\"",
    "Copied {origin} inside {destination}" : "Kopierte {origin} i {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Kopierte {origin} og {nbfiles} andre filer i {destination}",
    "{newName} already exists" : "{newName} finnes allerede",
    "Could not rename \"{fileName}\", it does not exist any more" : "Klarte ikke å omdøpe \"{fileName}\", den finnes ikke lenger",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Navnet \"{targetName}\" brukes allerede i mappen \"{dir}\". Velg et annet navn.",
    "Could not rename \"{fileName}\"" : "Klarte ikke å gi \"{fileName}\" nytt navn",
    "Could not create file \"{file}\"" : "Klarte ikke å opprette fil \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Klarte ikke å opprette fil \"{file}\" fordi den finnes allerede",
    "Could not create folder \"{dir}\" because it already exists" : "Klarete ikke å opprette mappe \"{dir}\" fordi den finnes allerede",
    "Error deleting file \"{fileName}\"." : "Feil ved sletting av fil \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Ingen søkeresultater i andre mapper etter {tag}{filter}{endtag}",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Endret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "_including %n hidden_::_including %n hidden_" : ["Inkludert %n skjult","Inkludert %n skjulte"],
    "You don’t have permission to upload or create files here" : "Du har ikke tillatelse til å laste opp eller opprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Laster opp %n fil","Laster opp %n filer"],
    "New" : "Ny",
    "{used} of {quota} used" : "{used} av {quota} brukt",
    "{used} used" : "{used} brukt",
    "\"{name}\" is an invalid file name." : "\"{name}\" er et uglydig filnavn.",
    "File name cannot be empty." : "Filnavn kan ikke være tomt.",
    "\"/\" is not allowed inside a file name." : "\"/\" tillates ikke i et filnavn.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" er ikke en tillatt filtype",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Lagringsplass for {owner} er full, filer kan ikke oppdateres eller synkroniseres lenger!",
    "Your storage is full, files can not be updated or synced anymore!" : "Lagringsplass er oppbrukt, filer kan ikke lenger oppdateres eller synkroniseres!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Lagringsplass for {owner} er nesten full ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Lagringsplass er nesten brukt opp ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : [" stemmer med '{filter}'"," stemmer med '{filter}'"],
    "View in folder" : "Vis i mappe",
    "Copied!" : "Kopiert!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopier direkte lenke (virker bare for brukere som har tilgang til denne filen/mappa)",
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n Byte"],
    "Favorited" : "Er favoritt",
    "Favorite" : "Gjør til favoritt",
    "New folder" : "Ny mappe",
    "Upload file" : "Last opp fil",
    "Not favorited" : "Ikke i favoritter",
    "Remove from favorites" : "Fjern fra favoritter",
    "Add to favorites" : "Legg til i favoritter",
    "An error occurred while trying to update the tags" : "En feil oppstod under oppdatering av merkelappene",
    "Added to favorites" : "Lagt til i favoritter",
    "Removed from favorites" : "Fjernet fra favoritter",
    "You added {file} to your favorites" : "Du la til {file} i dine favoritter",
    "You removed {file} from your favorites" : "Du fjernet {file} fra dine favoritter",
    "File changes" : "Filendringer",
    "Created by {user}" : "Opprettet av {user}",
    "Changed by {user}" : "Endret av {user}",
    "Deleted by {user}" : "Slettet av {user}",
    "Restored by {user}" : "Gjenopprettet av {user}",
    "Renamed by {user}" : "Navn endret av {user}",
    "Moved by {user}" : "Flyttet av {user}",
    "\"remote user\"" : "\"ekstern bruker\"",
    "You created {file}" : "Du opprettet {file}",
    "You created an encrypted file in {file}" : "Du opprettet en kryptert fil i {file}",
    "{user} created {file}" : "{user} opprettet {file}",
    "{user} created an encrypted file in {file}" : "{user} opprettet en kryptert fil i {file}",
    "{file} was created in a public folder" : "{file} ble opprettet i en offentlig mappe",
    "You changed {file}" : "Du endret {file}",
    "You changed an encrypted file in {file}" : "Du endret en kryptert fil i {file}",
    "{user} changed {file}" : "{user} endret {file}",
    "{user} changed an encrypted file in {file}" : "{user} endret en kryptert fil i {file}",
    "You deleted {file}" : "Du slettet {file}",
    "You deleted an encrypted file in {file}" : "Du slette en kryptert fil i {file}",
    "{user} deleted {file}" : "{user} slettet {file}",
    "{user} deleted an encrypted file in {file}" : "{user} slettet en kryptert fil i {file}",
    "You restored {file}" : "Du gjenopprettet {file}",
    "{user} restored {file}" : "{user} gjenopprettet {file}",
    "You renamed {oldfile} to {newfile}" : "Du endret navn på {oldfile} til {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} endret navn på {oldfile} til {newfile}",
    "You moved {oldfile} to {newfile}" : "Du flyttet {oldfile} til {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} flyttet {oldfile} til {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "En fil har blitt lagt til eller fjernet fra dine <strong>favoritter</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "En fil eller mappe ble <strong>endret</strong> eller <strong>omdøpt</strong>",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mappe ble <strong>opprettet</strong>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe ble <strong>slettet</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begrens varsling om oppretting og endringer til <strong>favorittfilene</strong> dine <em>(Kun strøm)</em>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe ble <strong>gjenopprettet</strong>",
    "Unlimited" : "Ubegrenset",
    "Upload (max. %s)" : "Opplasting (maks. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Største opplastingsstørrelse",
    "max. possible: " : "max. mulige:",
    "Save" : "Lagre",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Med PHP-FPM kan det ta 5 minutter før endringene trer i kraft.",
    "Missing permissions to edit from here." : "Manglende rettigheter til å redigere herfra.",
    "%s of %s used" : "%s av %s brukt",
    "%s used" : "%s brukt",
    "Settings" : "Innstillinger",
    "Show hidden files" : "Vis skjulte filer",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Bruk adressen <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">for å få tilgang til dine filer via WebDAV</a>",
    "Cancel upload" : "Avbryt opplasting",
    "No files in here" : "Ingen filer her",
    "Upload some content or sync with your devices!" : "Last opp noe innhold eller synkroniser med enhetene dine!",
    "No entries found in this folder" : "Ingen oppføringer funnet i denne mappen",
    "Select all" : "Velg alle",
    "Upload too large" : "Filen er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filene du prøver å laste opp er for store til å laste opp til denne tjeneren.",
    "No favorites yet" : "Ingen favoritter enda",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du gjør til favoritter vises her",
    "Tags" : "Merkelapper",
    "Deleted files" : "Slettede filer",
    "Shared with others" : "Delt med andre",
    "Shared with you" : "Delt med deg",
    "Shared by link" : "Delt med lenke",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekstfil.txt",
    "Move" : "Flytt",
    "A new file or folder has been <strong>deleted</strong>" : "En ny fil eller mappe har blitt <strong>slettet</strong>",
    "A new file or folder has been <strong>restored</strong>" : "En ny fil eller mappe har blitt <strong>gjenopprettet</strong>",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Bruk denne adressen <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">for å få tilgang til dine filer via WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");
